@@ -15,8 +15,9 @@ nn_inputs <- reactive({
   ## loop needed because reactive values don't allow single bracket indexing
   nn_args$data_filter <- if (input$show_filter) input$data_filter else ""
   nn_args$dataset <- input$dataset
-  for (i in r_drop(names(nn_args)))
+  for (i in r_drop(names(nn_args))) {
     nn_args[[i]] <- input[[paste0("nn_", i)]]
+  }
   nn_args
 })
 
@@ -29,8 +30,9 @@ nn_pred_args <- as.list(if (exists("predict.nn")) {
 # list of function inputs selected by user
 nn_pred_inputs <- reactive({
   # loop needed because reactive values don't allow single bracket indexing
-  for (i in names(nn_pred_args))
+  for (i in names(nn_pred_args)) {
     nn_pred_args[[i]] <- input[[paste0("nn_", i)]]
+  }
 
   nn_pred_args$pred_cmd <- nn_pred_args$pred_data <- ""
   if (input$nn_predict == "cmd") {
@@ -52,13 +54,14 @@ nn_pred_plot_args <- as.list(if (exists("plot.model.predict")) {
   formals(plot.model.predict)
 } else {
   formals(radiant.model:::plot.model.predict)
-} )
+})
 
 # list of function inputs selected by user
 nn_pred_plot_inputs <- reactive({
   # loop needed because reactive values don't allow single bracket indexing
-  for (i in names(nn_pred_plot_args))
+  for (i in names(nn_pred_plot_args)) {
     nn_pred_plot_args[[i]] <- input[[paste0("nn_", i)]]
+  }
   nn_pred_plot_args
 })
 
@@ -75,9 +78,9 @@ output$ui_nn_rvar <- renderUI({
   })
 
   init <- if (input$nn_type == "classification") {
-    if (is_empty(input$logit_rvar)) isolate(input$nn_rvar) else input$logit_rvar
+    if (radiant.data::is_empty(input$logit_rvar)) isolate(input$nn_rvar) else input$logit_rvar
   } else {
-    if (is_empty(input$reg_rvar)) isolate(input$nn_rvar) else input$reg_rvar
+    if (radiant.data::is_empty(input$reg_rvar)) isolate(input$nn_rvar) else input$reg_rvar
   }
 
   selectInput(
@@ -96,7 +99,7 @@ output$ui_nn_lev <- renderUI({
     as_factor() %>%
     levels()
 
-  init <- if (is_empty(input$logit_lev)) isolate(input$nn_lev) else input$logit_lev
+  init <- if (radiant.data::is_empty(input$logit_lev)) isolate(input$nn_lev) else input$logit_lev
   selectInput(
     inputId = "nn_lev", label = "Choose level:",
     choices = levs,
@@ -105,7 +108,9 @@ output$ui_nn_lev <- renderUI({
 })
 
 output$ui_nn_evar <- renderUI({
-  if (not_available(input$nn_rvar)) return()
+  if (not_available(input$nn_rvar)) {
+    return()
+  }
   vars <- varnames()
   if (length(vars) > 0) {
     vars <- vars[-which(vars == input$nn_rvar)]
@@ -113,10 +118,10 @@ output$ui_nn_evar <- renderUI({
 
   init <- if (input$nn_type == "classification") {
     # input$logit_evar
-    if (is_empty(input$logit_evar)) isolate(input$nn_evar) else input$logit_evar
+    if (radiant.data::is_empty(input$logit_evar)) isolate(input$nn_evar) else input$logit_evar
   } else {
     # input$reg_evar
-    if (is_empty(input$reg_evar)) isolate(input$nn_evar) else input$reg_evar
+    if (radiant.data::is_empty(input$reg_evar)) isolate(input$nn_evar) else input$reg_evar
   }
 
   selectInput(
@@ -136,7 +141,9 @@ output$ui_nn_wts <- renderUI({
   if (length(vars) > 0 && any(vars %in% input$nn_evar)) {
     vars <- base::setdiff(vars, input$nn_evar)
     names(vars) <- varnames() %>%
-      {.[match(vars, .)]} %>%
+      {
+        .[match(vars, .)]
+      } %>%
       names()
   }
   vars <- c("None", vars)
@@ -151,7 +158,7 @@ output$ui_nn_wts <- renderUI({
 output$ui_nn_store_pred_name <- renderUI({
   init <- state_init("nn_store_pred_name", "pred_nn") %>%
     sub("\\d{1,}$", "", .) %>%
-    paste0(., ifelse(is_empty(input$nn_size), "", input$nn_size))
+    paste0(., ifelse(radiant.data::is_empty(input$nn_size), "", input$nn_size))
   textInput(
     "nn_store_pred_name",
     "Store predictions:",
@@ -186,7 +193,8 @@ output$ui_nn_plots <- renderUI({
     nn_plots <- head(nn_plots, -1)
   }
   selectInput(
-    "nn_plots", "Plots:", choices = nn_plots,
+    "nn_plots", "Plots:",
+    choices = nn_plots,
     selected = state_single("nn_plots", nn_plots)
   )
 })
@@ -208,16 +216,18 @@ run_refresh(nn_args, "nn", tabs = "tabs_nn", label = "Estimate model", relabel =
 output$ui_nn <- renderUI({
   req(input$dataset)
   tagList(
-    conditionalPanel(condition = "input.tabs_nn == 'Summary'",
+    conditionalPanel(
+      condition = "input.tabs_nn == 'Summary'",
       wellPanel(
-        actionButton("nn_run", "Estimate model", width = "100%", icon = icon("play"), class = "btn-success")
+        actionButton("nn_run", "Estimate model", width = "100%", icon = icon("play", verify_fa = FALSE), class = "btn-success")
       )
     ),
     wellPanel(
       conditionalPanel(
         condition = "input.tabs_nn == 'Summary'",
         radioButtons(
-          "nn_type", label = NULL, c("classification", "regression"),
+          "nn_type",
+          label = NULL, c("classification", "regression"),
           selected = state_init("nn_type", "classification"),
           inline = TRUE
         ),
@@ -227,23 +237,28 @@ output$ui_nn <- renderUI({
         uiOutput("ui_nn_wts"),
         tags$table(
           tags$td(numericInput(
-            "nn_size", label = "Size:", min = 1, max = 20,
+            "nn_size",
+            label = "Size:", min = 1, max = 20,
             value = state_init("nn_size", 1), width = "77px"
           )),
           tags$td(numericInput(
-            "nn_decay", label = "Decay:", min = 0, max = 1,
+            "nn_decay",
+            label = "Decay:", min = 0, max = 1,
             step = .1, value = state_init("nn_decay", .5), width = "77px"
           )),
           tags$td(numericInput(
-            "nn_seed", label = "Seed:",
+            "nn_seed",
+            label = "Seed:",
             value = state_init("nn_seed", 1234), width = "77px"
-          ))
+          )),
+          width = "100%"
         )
       ),
       conditionalPanel(
         condition = "input.tabs_nn == 'Predict'",
         selectInput(
-          "nn_predict", label = "Prediction input type:", reg_predict,
+          "nn_predict",
+          label = "Prediction input type:", reg_predict,
           selected = state_single("nn_predict", reg_predict, "none")
         ),
         conditionalPanel(
@@ -277,7 +292,7 @@ output$ui_nn <- renderUI({
           "input.nn_predict == 'data' | input.nn_predict == 'datacmd'",
           tags$table(
             tags$td(uiOutput("ui_nn_store_pred_name")),
-            tags$td(actionButton("nn_store_pred", "Store", icon = icon("plus")), style = "padding-top:30px;")
+            tags$td(actionButton("nn_store_pred", "Store", icon = icon("plus", verify_fa = FALSE)), class = "top")
           )
         )
       ),
@@ -293,7 +308,7 @@ output$ui_nn <- renderUI({
         condition = "input.tabs_nn == 'Summary'",
         tags$table(
           tags$td(uiOutput("ui_nn_store_res_name")),
-          tags$td(actionButton("nn_store_res", "Store", icon = icon("plus")), style = "padding-top:30px;")
+          tags$td(actionButton("nn_store_res", "Store", icon = icon("plus", verify_fa = FALSE)), class = "top")
         )
       )
     ),
@@ -306,10 +321,16 @@ output$ui_nn <- renderUI({
 })
 
 nn_plot <- reactive({
-  if (nn_available() != "available") return()
-  if (is_empty(input$nn_plots, "none")) return()
+  if (nn_available() != "available") {
+    return()
+  }
+  if (radiant.data::is_empty(input$nn_plots, "none")) {
+    return()
+  }
   res <- .nn()
-  if (is.character(res)) return()
+  if (is.character(res)) {
+    return()
+  }
   if ("dashboard" %in% input$nn_plots) {
     plot_height <- 750
   } else if ("pdp" %in% input$nn_plots) {
@@ -321,14 +342,23 @@ nn_plot <- reactive({
   list(plot_width = 650, plot_height = plot_height)
 })
 
-nn_plot_width <- function()
-  nn_plot() %>% {if (is.list(.)) .$plot_width else 650}
+nn_plot_width <- function() {
+  nn_plot() %>%
+    {
+      if (is.list(.)) .$plot_width else 650
+    }
+}
 
-nn_plot_height <- function()
-  nn_plot() %>% {if (is.list(.)) .$plot_height else 500}
+nn_plot_height <- function() {
+  nn_plot() %>%
+    {
+      if (is.list(.)) .$plot_height else 500
+    }
+}
 
-nn_pred_plot_height <- function()
+nn_pred_plot_height <- function() {
   if (input$nn_pred_plot) 500 else 1
+}
 
 ## output is called from the main radiant ui.R
 output$nn <- renderUI({
@@ -409,20 +439,30 @@ nn_available <- reactive({
 })
 
 .summary_nn <- reactive({
-  if (not_pressed(input$nn_run)) return("** Press the Estimate button to estimate the model **")
-  if (nn_available() != "available") return(nn_available())
+  if (not_pressed(input$nn_run)) {
+    return("** Press the Estimate button to estimate the model **")
+  }
+  if (nn_available() != "available") {
+    return(nn_available())
+  }
   summary(.nn())
 })
 
 .predict_nn <- reactive({
-  if (not_pressed(input$nn_run)) return("** Press the Estimate button to estimate the model **")
-  if (nn_available() != "available") return(nn_available())
-  if (is_empty(input$nn_predict, "none")) return("** Select prediction input **")
+  if (not_pressed(input$nn_run)) {
+    return("** Press the Estimate button to estimate the model **")
+  }
+  if (nn_available() != "available") {
+    return(nn_available())
+  }
+  if (radiant.data::is_empty(input$nn_predict, "none")) {
+    return("** Select prediction input **")
+  }
 
-  if ((input$nn_predict == "data" || input$nn_predict == "datacmd") && is_empty(input$nn_pred_data)) {
+  if ((input$nn_predict == "data" || input$nn_predict == "datacmd") && radiant.data::is_empty(input$nn_pred_data)) {
     return("** Select data for prediction **")
   }
-  if (input$nn_predict == "cmd" && is_empty(input$nn_pred_cmd)) {
+  if (input$nn_predict == "cmd" && radiant.data::is_empty(input$nn_pred_cmd)) {
     return("** Enter prediction commands **")
   }
 
@@ -435,26 +475,27 @@ nn_available <- reactive({
 })
 
 .predict_print_nn <- reactive({
-  .predict_nn() %>% {
-    if (is.character(.)) cat(., "\n") else print(.)
-  }
+  .predict_nn() %>%
+    {
+      if (is.character(.)) cat(., "\n") else print(.)
+    }
 })
 
 .predict_plot_nn <- reactive({
   req(
     pressed(input$nn_run), input$nn_pred_plot,
     available(input$nn_xvar),
-    !is_empty(input$nn_predict, "none")
+    !radiant.data::is_empty(input$nn_predict, "none")
   )
 
   # if (not_pressed(input$nn_run)) return(invisible())
   # if (nn_available() != "available") return(nn_available())
   # req(input$nn_pred_plot, available(input$nn_xvar))
-  # if (is_empty(input$nn_predict, "none")) return(invisible())
-  # if ((input$nn_predict == "data" || input$nn_predict == "datacmd") && is_empty(input$nn_pred_data)) {
+  # if (radiant.data::is_empty(input$nn_predict, "none")) return(invisible())
+  # if ((input$nn_predict == "data" || input$nn_predict == "datacmd") && radiant.data::is_empty(input$nn_pred_data)) {
   #   return(invisible())
   # }
-  # if (input$nn_predict == "cmd" && is_empty(input$nn_pred_cmd)) {
+  # if (input$nn_predict == "cmd" && radiant.data::is_empty(input$nn_pred_cmd)) {
   #   return(invisible())
   # }
 
@@ -471,7 +512,7 @@ nn_available <- reactive({
     return(nn_available())
   }
   req(input$nn_size)
-  if (is_empty(input$nn_plots, "none")) {
+  if (radiant.data::is_empty(input$nn_plots, "none")) {
     return("Please select a neural network plot from the drop-down menu")
   }
   pinp <- list(plots = input$nn_plots, shiny = TRUE)
@@ -481,7 +522,10 @@ nn_available <- reactive({
   }
 
   if (input$nn_plots == "net") {
-    .nn() %>% {if (is.character(.)) invisible() else capture_plot(do.call(plot, c(list(x = .), pinp)))}
+    .nn() %>%
+      {
+        if (is.character(.)) invisible() else capture_plot(do.call(plot, c(list(x = .), pinp)))
+      }
   } else {
     withProgress(message = "Generating plots", value = 1, {
       do.call(plot, c(list(x = .nn()), pinp))
@@ -492,7 +536,9 @@ nn_available <- reactive({
 observeEvent(input$nn_store_res, {
   req(pressed(input$nn_run))
   robj <- .nn()
-  if (!is.list(robj)) return()
+  if (!is.list(robj)) {
+    return()
+  }
   fixed <- fix_names(input$nn_store_res_name)
   updateTextInput(session, "nn_store_res_name", value = fixed)
   withProgress(
@@ -502,9 +548,11 @@ observeEvent(input$nn_store_res, {
 })
 
 observeEvent(input$nn_store_pred, {
-  req(!is_empty(input$nn_pred_data), pressed(input$nn_run))
+  req(!radiant.data::is_empty(input$nn_pred_data), pressed(input$nn_run))
   pred <- .predict_nn()
-  if (is.null(pred)) return()
+  if (is.null(pred)) {
+    return()
+  }
   fixed <- fix_names(input$nn_store_pred_name)
   updateTextInput(session, "nn_store_pred_name", value = fixed)
   withProgress(
@@ -516,14 +564,16 @@ observeEvent(input$nn_store_pred, {
   )
 })
 
-observeEvent(input$nn_report, {
-  if (is_empty(input$nn_evar)) return(invisible())
+nn_report <- function() {
+  if (radiant.data::is_empty(input$nn_evar)) {
+    return(invisible())
+  }
 
   outputs <- c("summary")
   inp_out <- list(list(prn = TRUE), "")
   figs <- FALSE
 
-  if (!is_empty(input$nn_plots, "none")) {
+  if (!radiant.data::is_empty(input$nn_plots, "none")) {
     if (input$nn_type == "regression" && input$nn_plots == "dashboard") {
       inp_out[[2]] <- list(plots = input$nn_plots, nrobs = as_integer(input$nn_nrobs), custom = FALSE)
     } else {
@@ -533,7 +583,7 @@ observeEvent(input$nn_report, {
     figs <- TRUE
   }
 
-  if (!is_empty(input$nn_store_res_name)) {
+  if (!radiant.data::is_empty(input$nn_store_res_name)) {
     fixed <- fix_names(input$nn_store_res_name)
     updateTextInput(session, "nn_store_res_name", value = fixed)
     xcmd <- paste0(input$dataset, " <- store(", input$dataset, ", result, name = \"", fixed, "\")\n")
@@ -541,17 +591,17 @@ observeEvent(input$nn_report, {
     xcmd <- ""
   }
 
-  if (!is_empty(input$nn_predict, "none") &&
-    (!is_empty(input$nn_pred_data) || !is_empty(input$nn_pred_cmd))) {
+  if (!radiant.data::is_empty(input$nn_predict, "none") &&
+    (!radiant.data::is_empty(input$nn_pred_data) || !radiant.data::is_empty(input$nn_pred_cmd))) {
     pred_args <- clean_args(nn_pred_inputs(), nn_pred_args[-1])
 
-    if (!is_empty(pred_args$pred_cmd)) {
+    if (!radiant.data::is_empty(pred_args$pred_cmd)) {
       pred_args$pred_cmd <- strsplit(pred_args$pred_cmd, ";")[[1]]
     } else {
       pred_args$pred_cmd <- NULL
     }
 
-    if (!is_empty(pred_args$pred_data)) {
+    if (!radiant.data::is_empty(pred_args$pred_data)) {
       pred_args$pred_data <- as.symbol(pred_args$pred_data)
     } else {
       pred_args$pred_data <- NULL
@@ -563,12 +613,13 @@ observeEvent(input$nn_report, {
     if (input$nn_predict %in% c("data", "datacmd")) {
       fixed <- fix_names(input$nn_store_pred_name)
       updateTextInput(session, "nn_store_pred_name", value = fixed)
-      xcmd <- paste0(xcmd, "\n", input$nn_pred_data , " <- store(",
+      xcmd <- paste0(
+        xcmd, "\n", input$nn_pred_data, " <- store(",
         input$nn_pred_data, ", pred, name = \"", fixed, "\")"
       )
     }
 
-    if (input$nn_pred_plot && !is_empty(input$nn_xvar)) {
+    if (input$nn_pred_plot && !radiant.data::is_empty(input$nn_xvar)) {
       inp_out[[3 + figs]] <- clean_args(nn_pred_plot_inputs(), nn_pred_plot_args[-1])
       inp_out[[3 + figs]]$result <- "pred"
       outputs <- c(outputs, "plot")
@@ -591,7 +642,7 @@ observeEvent(input$nn_report, {
     fig.height = nn_plot_height(),
     xcmd = xcmd
   )
-})
+}
 
 dl_nn_pred <- function(path) {
   if (pressed(input$nn_run)) {
@@ -630,3 +681,18 @@ download_handler(
   width = nn_plot_width,
   height = nn_plot_height
 )
+
+observeEvent(input$nn_report, {
+  r_info[["latest_screenshot"]] <- NULL
+  nn_report()
+})
+
+observeEvent(input$nn_screenshot, {
+  r_info[["latest_screenshot"]] <- NULL
+  radiant_screenshot_modal("modal_nn_screenshot")
+})
+
+observeEvent(input$modal_nn_screenshot, {
+  nn_report()
+  removeModal() ## remove shiny modal after save
+})
\ No newline at end of file
